@@ -16,7 +16,7 @@ def reload_gala():
     this is just a workaround until this issue (https://github.com/elementary/gala/issues/13)
     gets fixed
     """
-    subprocess.Popen(['gala', '-r'],
+    return subprocess.Popen(['gala', '-r'],
                      stderr=subprocess.DEVNULL,
                      stdout=subprocess.DEVNULL)
 
@@ -42,7 +42,7 @@ def change_background(photo_name: str):
     determined by operating system
     """
     cmd = get_background_cmd(photo_name)
-    subprocess.call(cmd)
+    return subprocess.call(cmd)
 
 
 def get_screen_size():
